---
title: date.quarter() function
description: >
  The `date.quarter()` function returns the quarter of the year for a specified time.
  Results range from `[1-4]`.
aliases:
  - /v2.0/reference/flux/functions/date/quarter/
menu:
  v2_0_ref:
    name: date.quarter
    parent: Date
weight: 301
---

The `date.quarter()` function returns the quarter of the year for a specified time.
Results range from `[1-4]`.

_**Function type:** Transformation_  

```js
import "date"

date.quarter(t: 2019-07-17T12:05:21.012Z)

// Returns 3
```

## Parameters

### t
The time to operate on.
Use an absolute time, relative duration, or integer.
Durations are relative to `now()`.
Integers are **nanosecond** [Unix timestamps](/v2.0/reference/glossary/#unix-timestamp).

_**Data type:** Time | Duration | Integer_

## Examples

##### Return the quarter for a time value
```js
import "date"

date.quarter(t: 2020-02-11T12:21:03.293534940Z)

// Returns 1
```

##### Return the quarter for a relative duration
```js
import "date"

option now = () => 2020-02-11T12:21:03.293534940Z

date.quarter(t: -7mo)

// Returns 3
```

##### Return the quarter for a nanosecond Unix timestamp
```js
import "date"

date.quarter(t: 1581423663293534940)

// Returns 1
```
