---
title: date.weekDay() function
description: >
  The `date.weekDay()` function returns the day of the week for a specified time.
  Results range from `[0-6]`.
aliases:
  - /v2.0/reference/flux/functions/date/weekday/
menu:
  v2_0_ref:
    name: date.weekDay
    parent: Date
weight: 301
---

The `date.weekDay()` function returns the day of the week for a specified time.
Results range from `[0-6]`.

_**Function type:** Transformation_  

```js
import "date"

date.weekDay(t: 2019-07-17T12:05:21.012Z)

// Returns 3
```

## Parameters

### t
The time to operate on.
Use an absolute time, relative duration, or integer.
Durations are relative to `now()`.
Integers are **nanosecond** [Unix timestamps](/v2.0/reference/glossary/#unix-timestamp).

_**Data type:** Time | Duration | Integer_

## Examples

##### Return the day of the week for a time value
```js
import "date"

date.weekDay(t: 2020-02-11T12:21:03.293534940Z)

// Returns 2
```

##### Return the day of the week for a relative duration
```js
import "date"

option now = () => 2020-02-11T12:21:03.293534940Z

date.weekDay(t: -84h)

// Returns 6
```

##### Return the day of the week for a nanosecond Unix timestamp
```js
import "date"

date.weekDay(t: 1581423663293534940)

// Returns 2
```
